//************************** s609drv.h ***************************
//* This file contains constant & type definitions and function
//* prototypes for using Sensoray Model 609 loadable Linux device
//* driver (supporting GPIO access and Crosspoint Switch control).
//*
//* Autor:		Charlie X. Liu
//*
//* Revision:		03/18/03   0.0   initial
//*
//* Copyright (C) 2003	Sensoray Co., Inc.
//****************************************************************


//*-------------------------------------------------------
//* Constants
//*-------------------------------------------------------

/* s609drv major number */
#define S609_MAJOR		       209

/* Bt878 base address   */
//#define Bt878_BASE_ADDR	0x80100000
//#define Bt878_BASE_ADDR	0xde100000

/*------------------------------------------
 * Register addresses
 *------------------------------------------*/
#define DSTATUS                      0x000
#define IFORM                        0x004
#define TDEC                         0x008
#define E_CROP                       0x00c
#define O_CROP                       0x08c
#define E_VDELAY_LO                  0x010
#define O_VDELAY_LO                  0x090
#define E_VACTIVE_LO                 0x014
#define O_VACTIVE_LO                 0x094
#define E_DELAY_LO                   0x018
#define O_DELAY_LO                   0x098
#define E_HACTIVE_LO                 0x01c
#define O_HACTIVE_LO                 0x09c
#define E_HSCALE_HI                  0x020
#define O_HSCALE_HI                  0x0a0
#define E_HSCALE_LO                  0x024
#define O_HSCALE_LO                  0x0a4
#define R_BRIGHT                     0x028
#define E_CONTROL                    0x02c
#define O_CONTROL                    0x0ac
#define CONTRAST_LO                  0x030
#define SAT_U_LO                     0x034
#define SAT_V_LO                     0x038
#define R_HUE                        0x03c
#define E_SCLOOP                     0x040
#define O_SCLOOP                     0x0c0
#define OFORM                        0x048
#define E_VSCALE_HI                  0x04c
#define O_VSCALE_HI                  0x0cc
#define E_VSCALE_LO                  0x050
#define O_VSCALE_LO                  0x0d0
#define R_ADELAY                     0x060
#define R_BDELAY                     0x064
#define ADC                          0x068
#define E_VTC                        0x06c
#define O_VTC                        0x0ec
#define SRESET                       0x07c
#define TGCTRL                       0x084
#define COLOR_FMT                    0x0d4
#define COLOR_CTL                    0x0d8
#define CAP_CTL                      0x0dc
#define PLL_F_LO                     0x0f0
#define PLL_F_HI                     0x0f4
#define PLL_XCI                      0x0f8
#define DVSIF                        0x0fc
#define FCAP                         0x0e8
#define INT_STAT                     0x100
#define INT_MASK                     0x104
#define GPIO_DMA_CTL                 0x10c
#define I2C_DC                       0x110
#define RISC_START                   0x114
#define GPIO_OUT_EN                  0x118
#define GPIO_REG_INP                 0x11c
#define RISC_COUNT                   0x120
#define GPIO_DATA                    0x200

// GPIO constants
#define SER_CE			   0x80000		//chip enable
#define SER_LATCH		   0x40000		//latch
#define SER_WR			   0x20000		//write
#define SER_DATA		   0x10000		//data
//
#define TERM_CLK		  0x100000		//termination buffer clock bit
#define IO_WR			  0x400000		//digital IO write
#define IO_RD			  0x200000		//digital IO read
//
#define CTRL_IDLE		  0x2d0000		//idle value of control bits [16:22]
#define GPIO_EN_RD		  0x7f0000		//GPIO out enables in read mode
#define GPIO_EN_WR		  0x7fffff		//GPIO out enables in write mode

// S609 Hardware dependent constants
#define F878_DEVICE_ID		    0x036e          	//Fusion878, Function 0
#define F878_VENDOR_ID		    0x109e          	//Conexant
#define S609_SUBID		0x06096000		//0609 (sub ID), 6000 (sub vendor ID)
#define S609_SUBSYS_ID		    0x0609		//subsystem ID
#define S609_SUBSYS_VENDOR_ID	    0x6000		//subsystem vendor ID
#define SUBOFFSET		      0x2c		//offset of SubID's in config space
#define CSROFFSET		      0x04		//offset of CSR in config space
#define CSRENABLE		      0x03		//enable bus mastering and memory space access

// 609 sys constants
#define SYS_MAXGRABBERS         	 8		//max fg's supported;
#define SYS_VOUT			 8		//number of video switch output channels
#define SYS_VIN				16		//number of video switch input channels
#define SYS_ACTIVATE			 9		//"activate" code for the video mux


/* common */
#define BYTE	unsigned char
#define WORD	unsigned short
#define DWORD	unsigned long		// unsigned int
#define BOOL	int
//
#define TRUE	1
#define FALSE	0


//*-------------------------------------------------------
//* Structures
//*-------------------------------------------------------

struct ioparam			// IOCTL data
{
  unsigned long param1;		// data			or	 in#
  unsigned long param2;		// <reg_addr_offset>	or	out#
};

typedef struct {		//video switch data
	WORD input;		//selected input
	BOOL termination;	//output on (TRUE) / off (FALSE)
} VSMODE;


//*-------------------------------------------------------
//* Driver commands
//*-------------------------------------------------------
							//      params
							//   b  r/w  p1   p2
#define  RegRD          _IOWR(S609_MAJOR,0,void *)	//   h   i  dat  reg
#define  RegWR          _IOWR(S609_MAJOR,1,void *)	//   h   o  dat  reg
#define  DioRD          _IOWR(S609_MAJOR,2,void *)	//   h   i  dat
#define  DioWR          _IOWR(S609_MAJOR,3,void *)	//   h   o  dat
#define  XptSW          _IOWR(S609_MAJOR,4,void *)	//   h   o  in#  out#

